==> billogram-foundation-4.7.1.tgz: package/modules/components/textbox/Textbox.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import isNullOrEmpty from '../../utils/isNullOrEmpty';
import toNumber from './utils/toNumber';


export default ({
    block,
    displayName
} = {}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            disabled: PropTypes.bool,
            error: PropTypes.bool,
            focus: PropTypes.bool,
            maxLength: PropTypes.oneOfType([
                PropTypes.number,
                PropTypes.string
            ]),
            name: PropTypes.string,
            onBlur: PropTypes.func,
            onChange: PropTypes.func,
            onFocus: PropTypes.func,
            placeholder: PropTypes.string,
            tabbable: PropTypes.bool,
            type: PropTypes.oneOf([
                'float',
                'integer',
                'integer-positive-only',
                'password',
                'text'
            ]),
            value: PropTypes.string
        },

        getDefaultProps() {
            return {
                disabled: false,
                error: false,
                focus: false,
                name: null,
                onBlur: () => {},
                onChange: (/* { rawValue, value } */) => {},
                onFocus: () => {},
                placeholder: null,
                tabbable: true,
                type: 'text',
                value: ''
            };
        },

        componentDidMount() {
            if (this.props.focus) {
                this.focus();
            }
        },

        onChange(evt) {
            const { onChange, type } = this.props;

            const rawValue = evt.target.value;
            const { value, valid } = type === 'float' || type === 'integer' || type === 'integer-positive-only'
                ? toNumber(rawValue, type)
                : { value: rawValue, valid: true };

            if (valid) {
                onChange({ rawValue, value });
            }
        },

        onKeyDown(evt) {
            switch (evt.which) {
                // Stop propagation for left/right arrow which useful when textbox is
                // in custom radio button group as otherwise we won't be able to select text.
                // However, you still want to be able to navigate between different radio button
                // option which still is possible with up/down arrows.
                case 37:
                case 39:
                    evt.stopPropagation();
                    break;

                default:
                    break;
            }

        },

        focus() {
            this.component.focus();
            this.component.select();
        },

        render() {
            const { disabled, error, maxLength, name, onBlur, onFocus, placeholder, tabbable, type, value } = this.props;
            return (
                <input
                    className={ block({ disabled, error }) }
                    disabled={ disabled }
                    maxLength={ maxLength }
                    name={ name }
                    onBlur={ onBlur }
                    onChange={ this.onChange }
                    onFocus={ onFocus }
                    onKeyDown={ this.onKeyDown }
                    placeholder={ placeholder }
                    ref={ (c) => this.component = c }
                    tabIndex={ tabbable ? '0' : '-1' }
                    type={ type === 'password' ? 'password' : 'text' }
                    value={ value } />
            );
        }

    });

};

==> billogram-foundation-4.7.3.tgz: package/modules/components/textbox/Textbox.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import isNullOrEmpty from '../../utils/isNullOrEmpty';
import toNumber from './utils/toNumber';


export default ({
    block,
    displayName,
    uiPropDefaultType = PropTypes.string,
    uiPropDefaultValue = '',
    uiPropGetValue = (ui) => ui
} = {}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            disabled: PropTypes.bool,
            error: PropTypes.bool,
            focus: PropTypes.bool,
            maxLength: PropTypes.oneOfType([
                PropTypes.number,
                PropTypes.string
            ]),
            name: PropTypes.string,
            onBlur: PropTypes.func,
            onChange: PropTypes.func,
            onFocus: PropTypes.func,
            placeholder: PropTypes.string,
            tabbable: PropTypes.bool,
            type: PropTypes.oneOf([
                'float',
                'integer',
                'integer-positive-only',
                'password',
                'text'
            ]),
            ui: uiPropDefaultType,
            value: PropTypes.string
        },

        getDefaultProps() {
            return {
                disabled: false,
                error: false,
                focus: false,
                name: null,
                onBlur: () => {},
                onChange: (/* { rawValue, value } */) => {},
                onFocus: () => {},
                placeholder: null,
                tabbable: true,
                type: 'text',
                ui: uiPropDefaultValue,
                value: ''
            };
        },

        componentDidMount() {
            if (this.props.focus) {
                this.focus();
            }
        },

        onChange(evt) {
            const { onChange, type } = this.props;

            const rawValue = evt.target.value;
            const { value, valid } = type === 'float' || type === 'integer' || type === 'integer-positive-only'
                ? toNumber(rawValue, type)
                : { value: rawValue, valid: true };

            if (valid) {
                onChange({ rawValue, value });
            }
        },

        onKeyDown(evt) {
            switch (evt.which) {
                // Stop propagation for left/right arrow which useful when textbox is
                // in custom radio button group as otherwise we won't be able to select text.
                // However, you still want to be able to navigate between different radio button
                // option which still is possible with up/down arrows.
                case 37:
                case 39:
                    evt.stopPropagation();
                    break;

                default:
                    break;
            }

        },

        focus() {
            this.component.focus();
            this.component.select();
        },

        render() {
            const { disabled, error, maxLength, name, onBlur, onFocus, placeholder, tabbable, type, ui, value } = this.props;
            return (
                <input
                    className={ block({ disabled, error, ui: uiPropGetValue(ui) }) }
                    disabled={ disabled }
                    maxLength={ maxLength }
                    name={ name }
                    onBlur={ onBlur }
                    onChange={ this.onChange }
                    onFocus={ onFocus }
                    onKeyDown={ this.onKeyDown }
                    placeholder={ placeholder }
                    ref={ (c) => this.component = c }
                    tabIndex={ tabbable ? '0' : '-1' }
                    type={ type === 'password' ? 'password' : 'text' }
                    value={ value } />
            );
        }

    });

};
